@@ -1,6 +1,6 @@
 from simpleicons.icon import Icon
 icon= Icon(
-    title="Farfetch",
+    title="FARFETCH",
     slug="farfetch",
     hex="000000",
     source="https://www.farfetch.com/",
