@@ -5,6 +5,6 @@ icon= Icon(
     hex="FF6666",
     source="https://support.giphy.com/hc/en-us/articles/360022283772-GIPHY-Brand-Guidelines",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>GIPHY icon</title><path d="M2.666 0v24h18.668V8.666l-2.668 2.668v10H5.334V2.668H10L12.666 0zm10.668 0v8h8V5.334h-2.668V2.668H16V0"/></svg>""",
-    guidelines=None,
+    guidelines='https://support.giphy.com/hc/en-us/articles/360022283772-GIPHY-Brand-Guidelines',
     license=None,
 )
