@@ -3,7 +3,7 @@ icon= Icon(
     title="HomeAdvisor",
     slug="homeadvisor",
     hex="F68315",
-    source="https://www.abouthomeadvisor.com/media-room/press-resources/",
+    source="https://www.homeadvisor.com/",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>HomeAdvisor icon</title><path d="M15.98 2.442H8.02L0 10.46h2.275l6.882-6.88 6.881 6.881H24l-8.02-8.018m-.492 9.348L9.157 5.459 4.01 10.605v4.987a1.33 1.33 0 0 0 1.329 1.329h6.077l4.637 4.637v-4.637h2.598a1.33 1.33 0 0 0 1.33-1.33V11.79h-4.494Z"/></svg>""",
     guidelines=None,
     license=None,
