@@ -3,7 +3,7 @@ icon= Icon(
     title="Informatica",
     slug="informatica",
     hex="FF4D00",
-    source="https://www.informatica.com/content/dam/informatica-com/en/images/cc02v2/logo-informatica.svg",
+    source="https://www.informatica.com/",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Informatica icon</title><path d="M12 0l3.547 10.788-4.5-1.255-.25 4.43 7.121 4.035V18h.001l5.919-6zm-.64.65L.162 12l6.32 6.407L12 24l5.184-5.255-9.736-3.856z"/></svg>""",
     guidelines=None,
     license=None,
