@@ -3,8 +3,8 @@ icon= Icon(
     title="Plex",
     slug="plex",
     hex="E5A00D",
-    source="http://brand.plex.tv/d/qxmJ3odkK0fj/plex-style-guide",
+    source="https://brand.plex.tv/",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Plex icon</title><path d="M11.643 0H4.68l7.679 12L4.68 24h6.963l7.677-12-7.677-12"/></svg>""",
-    guidelines=None,
+    guidelines='https://brand.plex.tv/',
     license=None,
 )
